Learn R Programming

QHScrnomo (version 3.0.2)

anova.cmprsk: ANOVA Table for a Competing Risks Regression Model

Description

Uses the anova.rms method to construct an analysis of variance table for the competing risks regression model fit from crr.fit.

Usage

# S3 method for cmprsk
anova(object,...)

Value

An anova.rms matrix

Arguments

object

A model fit by crr.fit

...

Not used

Author

Changhong Yu. Department of Quantitative Health Sciences, Cleveland Clinic

See Also

crr.fit anova.rms

Examples

Run this code
dd <- datadist(prostate.dat)
options(datadist = "dd")
prostate.f <- cph(Surv(TIME_EVENT,EVENT_DOD == 1) ~ TX  + rcs(PSA,3) +
           BX_GLSN_CAT +  CLIN_STG + rcs(AGE,3) +
           RACE_AA, data = prostate.dat,
           x = TRUE, y = TRUE, surv = TRUE,time.inc = 144)
prostate.crr <- crr.fit(prostate.f, cencode = 0, failcode = 1)
anova(prostate.crr)

Run the code above in your browser using DataLab